
clear
macro drop _all
program drop _all
set more off
set linesize 80
version 9.0

capture log close
log using "/project/graf_schwartz/demresearch/baseline.log",replace

set mem 900m
set matsize 5000



**PURPOSE: This program calculates the odds of homogamy (or other
**         association parameters) for different-sex married couples
**         using a simplified log-linear model.



use if (age0 >= 20 & age0 <= 34) & (age1 >= 20 & age1 <= 34)  using "/project/graf_schwartz/demresearch/couple_2000.dta"
gen y = 2000

append using "/project/graf_schwartz/demresearch/couple_1990.dta"
replace y = 1990 if y == .



**********
* SELECT *
**********

keep if (age0 >= 20 & age0 <= 34) & (age1 >= 20 & age1 <= 34)

*drop couples in which either partners' marital status was imputed

gen marimp = (qmarst0 ~= 0 | qmarst1 ~= 0)


bysort y rel_var: tab marimp


drop if marimp == 1


bysort y: tab rel_var
bysort y: tab rel_var [fw=hhwt]



***FOR NOW, use the person weight of the householder.  This means the sample
***         is representative of relationships among 20-34 year old household
***         heads.



***USE ALTERNATIVE RACE VARIABLE***

   replace re1 = re21 if y == 2000
   replace re0 = re20 if y == 2000

   drop re2*



   foreach i in agec educ re {

    gen o_`i' = (`i'0 == `i'1)

   }




******************************
* DEAL WITH THE WEIGHTS HERE *
******************************

     #delimit ;

     ***This part deflates the weights so that the original
        sample size is maintained ;


        bysort rel_var: egen double sumwgt = sum(hhwt) ;
        bysort rel_var: gen N = _N  ;


        bysort rel_var: gen double deflate = N/sumwgt ;



        *preserve original weight variables ;
         gen oweight = hhwt ;

        bysort rel_var: gen double WEIGHT = oweight*deflate ;




#delimit cr



*******************************
* LOG-LINEAR MODEL EQUIVALENT *
*******************************

 preserve

  gen freq = 1

  collapse (sum) WEIGHT, by(agec1 agec0 educ1 educ0 re1 re0 rel_var y)
  sort agec1 agec0 educ1 educ0 re1 re0 rel_var y
  tempfile nozeros
  save `nozeros'

 restore


 *Add on zeros*

  contract agec1 agec0 educ1 educ0 re1 re0 rel_var y, freq(freqs) zero
  sort agec1 agec0 educ1 educ0 re1 re0 rel_var y
  merge agec1 agec0 educ1 educ0 re1 re0 rel_var y using `nozeros'

       replace WEIGHT = 0 if freqs == 0



   foreach i in agec educ re {

    gen o_`i' = (`i'0 == `i'1)

   }



     ***Generate linear age term for UA

       foreach num of numlist 0 1 {
        gen     agecl`num' = 22 if agec`num' == 1
        replace agecl`num' = 27 if agec`num' == 2
        replace agecl`num' = 32 if agec`num' == 3
       }

      gen uaagec = agecl1*agecl0
      gen abs_aged = abs(agecl1-agecl0)


***CROSSINGS VARIABLES***

   gen dc2 = (educ1 < 2 & educ0 >= 2) | (educ1 >= 2 & educ0 < 2)
   gen dc3 = (educ1 < 3 & educ0 >= 3) | (educ1 >= 3 & educ0 < 3)
   gen dc4 = (educ1 < 4 & educ0 >= 4) | (educ1 >= 4 & educ0 < 4)



preserve
keep if y == 1990


  #delimit ;
  xi: glm WEIGHT i.agec1*i.rel_var
                   i.agec0*i.rel_var
                   i.educ1*i.rel_var
                   i.educ0*i.rel_var
                   i.re1*i.rel_var
                   i.re0*i.rel_var
                     i.rel_var*o_re
                     i.rel_var*abs_aged
                     i.rel_var*dc2
                     i.rel_var*dc3
                     i.rel_var*dc4
                     , family(poisson) link(log) eform ;

restore ;


preserve ;

keep if y == 2000 ;


  #delimit ;
  xi: glm WEIGHT i.agec1*i.rel_var
                   i.agec0*i.rel_var
                   i.educ1*i.rel_var
                   i.educ0*i.rel_var
                   i.re1*i.rel_var
                   i.re0*i.rel_var
                     i.rel_var*o_re
                     i.rel_var*abs_aged
                     i.rel_var*dc2
                     i.rel_var*dc3
                     i.rel_var*dc4
                     , family(poisson) link(log) eform ;

restore ;

log close ;




