**************************************************************************
* SAMPLE: Use only couples in which both partners are between the ages of*
* 20-34                                                                  *
**************************************************************************


clear
macro drop _all
program drop _all
set more off
set linesize 80

capture log close
log using "marginals.log",replace

set mem 2000m




use if age >= 20 & age <= 34 using "individual_1990.dta"
gen ycat = 1


append using "individual_2000.dta"
replace ycat = 2 if ycat == .

lab def ycat 1 "1990" 2 "2000"
lab val ycat ycat


**********
* SELECT *
**********


keep if age >= 20 & age <=34

*Need to keep couples in which both partners are 20 to 34

gen age2034 = (age >= 20 & age <=34)
bysort ycat serial: egen both2034 = sum(age2034)

keep if age2034 == 1
keep if both2034 == 2


*Want to delete couples in which either partners' martial status
*has been allocated. For qmarst 0 = nonallocated and 4 = allocated.
*Couples in which the sum of qmarst = 8 or 4 should be dropped.

bysort ycat serial: egen sumalc = sum(qmarst)
drop if sumalc == 8 | sumalc == 4 | sumalc == .

*drop people that don't have partners
bysort ycat serial: drop if _N ~= 2

tab rel_var ycat


*********************************
* CODE biracial whites as white *
*********************************

replace re = re2 if (ycat == 2 | ycat == 3)

drop re2

***************************
* Marginal distributions  *
***************************


bysort rel_var sex ycat: tab re [aw=hhw]
bysort rel_var sex ycat: tab educ [aw=hhw]
bysort rel_var sex ycat: summarize age [aw=hhw] , detail


bysort rel_var ycat: tab re [aw=hhw]
bysort rel_var ycat: tab educ [aw=hhw]
bysort rel_var ycat: summarize age [aw=hhw] , detail
bysort rel_var ycat: summarize age, detail


log close



