
**************************************************************************
* SAMPLE: Use only couples in which both partners are between the ages of*
* 20-34                                                                  *
**************************************************************************

************************************************************************
* This file uses the alternate version of race/ethnicity in which      *
* biracial whites are coded as white                                   *
************************************************************************


clear
macro drop _all
program drop _all
set more off
set linesize 80
version 9.0

capture log close
log using "models_desc_20to34_unwt.log",replace

set mem 900m




use if (age0 >= 20 & age0 <= 34) & (age1 >= 20 & age1 <= 34)  using "couple_2000.dta"
gen y = 2000

append using "couple_1990.dta"
replace y = 1990 if y == .



svyset [pweight=hhwt]
svydes


**********
* SELECT *
**********

keep if (age0 >= 20 & age0 <= 34) & (age1 >= 20 & age1 <= 34)

bysort y: tab rel_var
bysort y: tab rel_var [fw=hhwt]





*Note that the survey command is equal to the frequency weights.
*The frequency weights take much less time to run so I use frequency weights
*for the crosstabs

svy: tab rel_var if y == 2000



*drop couples in which either partners' marital status was imputed

gen marimp = (qmarst0 ~= 0 | qmarst1 ~= 0)


bysort y rel_var: tab marimp


drop if marimp == 1


bysort y: tab rel_var
bysort y: tab rel_var [fw=hhwt]



***FOR NOW, use the person weight of the householder.  This means the sample
***         is representative of relationships among 20-34 year old household
***         heads.



***USE ALTERNATIVE RACE VARIABLE***

   replace re1 = re21 if y == 2000
   replace re0 = re20 if y == 2000

   drop re2*


***HOMOGAMY VARIABLES AND DESCRIPTIVES ***


  **(For point estimates of correlation coefficients with survey
  ** data use aweights. See  http://www.stata.com/support/faqs/stat/survey.html)

   foreach i in age educ_l re {

    gen o_`i' = (`i'0 == `i'1)

    bysort rel_var: corr `i'0 `i'1  [aw=hhwt]
    tab rel_var o_`i' [fw=hhwt],nofreq row

   }




***RACE/ETHNICITY DIAGONAL***

   forvalues i = 1/4 {
    gen o_re_`i' = (re0 == re1 & re0 == `i')
   }



***SYMMETRY RACE/ETHNICITY***

   gen     sym_re = 1 if (re1 == 1 & re0 == 1)
   replace sym_re = 2 if (re1 == 2 & re0 == 1) | (re1 == 1 & re0 == 2)
   replace sym_re = 3 if (re1 == 3 & re0 == 1) | (re1 == 1 & re0 == 3)
   replace sym_re = 4 if (re1 == 4 & re0 == 1) | (re1 == 1 & re0 == 4)
   replace sym_re = 5 if (re1 == 2 & re0 == 2)
   replace sym_re = 6 if (re1 == 3 & re0 == 2) | (re1 == 2 & re0 == 3)
   replace sym_re = 7 if (re1 == 4 & re0 == 2) | (re1 == 2 & re0 == 4)
   replace sym_re = 8 if (re1 == 3 & re0 == 3)
   replace sym_re = 9 if (re1 == 3 & re0 == 4) | (re1 == 4 & re0 == 3)
   replace sym_re =10 if (re1 == 4 & re0 == 4)



***AGE DIFFERENCES AND DESCRIPTIVES***

   gen age_d = abs(age0-age1)
   table rel_var [fw=hhwt], c(med age_d mean age_d)

   gen age_5d = (age_d >= 5 & age_d ~= . )
   tab rel_var age_5d [fw=hhwt], nofreq row


     ***Generate linear age term for UA

       foreach num of numlist 0 1 {
        gen     agecl`num' = 22 if agec`num' == 1
        replace agecl`num' = 27 if agec`num' == 2
        replace agecl`num' = 32 if agec`num' == 3
       }

      gen uaagec = agecl1*agecl0
      gen abs_aged = abs(agecl1-agecl0)



***DETAILED RACE/ETH DESCRIPTIVES**

   bysort rel_var: tab re1 re0 [fw=hhwt], row col cell nofreq


***CROSSINGS VARIABLES***

   gen dc2 = (educ1 < 2 & educ0 >= 2) | (educ1 >= 2 & educ0 < 2)
   gen dc3 = (educ1 < 3 & educ0 >= 3) | (educ1 >= 3 & educ0 < 3)
   gen dc4 = (educ1 < 4 & educ0 >= 4) | (educ1 >= 4 & educ0 < 4)


***UNIFORM ASSOCIATION, EDUCATION***

   gen uaeduc = educ_l1*educ_l0
   gen abs_edd = abs(educ_l1-educ_l0)



***Either partner in couple geographically mobile***

   gen gmc = (geog_mob1 == 1 | geog_mob0 == 1)
   tab rel_var gmc [fw=hhwt], nofreq row



***Bi-variate relationship between homogamy and geographic mobility

   tab o_educ gmc , chi2 col nofreq
   tab o_re gmc , chi2 col nofreq
   ttest age_d, by(gmc)





******************************
* DEAL WITH THE WEIGHTS HERE *
******************************

     #delimit ;

     ***This part deflates the weights so that the original
        sample size is maintained ;


        bysort rel_var: egen double sumwgt = sum(hhwt) ;
        bysort rel_var: gen N = _N  ;


        bysort rel_var: gen double deflate = N/sumwgt ;



        *preserve original weight variables ;
         gen oweight = hhwt ;

        bysort rel_var: gen double WEIGHT = oweight*deflate ;




#delimit cr




***************************
* Run a multinomial logit *
***************************


local base = "i.agec1*i.y i.agec0*i.y i.educ1*i.y i.educ0*i.y i.re1*i.y i.re0*i.y"



**********************
* UNWEIGHTED RESULTS *
**********************




**Baseline model

  xi: mlogit rel_var `base', rrr base(1)


**Test for differences in age associations

  xi: mlogit rel_var `base' uaagec , rrr base(1)
  xi: mlogit rel_var `base' abs_aged , rrr base(1)


**Test for differences in sorting by race/ethnicity

  xi: mlogit rel_var `base' abs_aged o_re , rrr base(1)
  xi: mlogit rel_var `base' abs_aged o_re_* , rrr base(1)
  xi: mlogit rel_var `base' abs_aged i.sym_re , rrr base(1)


**Test for differences in sorting by education

  xi: mlogit rel_var `base' abs_aged o_re o_educ , rrr base(1)
 *xi: mlogit rel_var `base' abs_aged o_re uaeduc , rrr base(1)
  xi: mlogit rel_var `base' abs_aged o_re abs_edd , rrr base(1)
  xi: mlogit rel_var `base' abs_aged o_re dc2 dc3 dc4 , rrr base(1)



**Have differences changed over time?


  xi: mlogit rel_var `base' i.y*abs_aged o_re dc2 dc3 dc4 , rrr base(1)
  est store yage

  xi: mlogit rel_var `base' i.y*abs_aged i.y*o_re dc2 dc3 dc4 , rrr base(1)
  lrtest yage


  xi: mlogit rel_var `base' i.y*abs_aged o_re i.y*dc2 i.y*dc3 i.y*dc4 , rrr base(1)
  lrtest yage






  xi: mlogit rel_var `base' i.y*abs_aged i.y*o_re i.y*dc2 i.y*dc3 i.y*dc4 , rrr base(1)


  lincom [2]_IyXdc3_2000 + [2]_IyXdc4_2000
  scalar def hsc_cvm = r(estimate)
  scalar def hsc_cvm_se = r(se)
  scalar def hsc_cvm_z = hsc_cvm/hsc_cvm_se
  scalar def hsc_cvm_p=2*(1-norm(abs(hsc_cvm_z)))


  lincom [3]_IyXdc3_2000 + [3]_IyXdc4_2000
  scalar def hsc_ssfvm = r(estimate)
  scalar def hsc_ssfvm_se = r(se)
  scalar def hsc_ssfvm_z = hsc_ssfvm/hsc_ssfvm_se
  scalar def hsc_ssfvm_p=2*(1-norm(abs(hsc_ssfvm_z)))

  lincom [4]_IyXdc3_2000 + [4]_IyXdc4_2000
  scalar def hsc_ssmvm = r(estimate)
  scalar def hsc_ssmvm_se = r(se)
  scalar def hsc_ssmvm_z = hsc_ssmvm/hsc_ssmvm_se
  scalar def hsc_ssmvm_p=2*(1-norm(abs(hsc_ssmvm_z)))

  lincom [2]_IyXdc2_2000 + [2]_IyXdc3_2000 + [2]_IyXdc4_2000
  scalar def lhsc_cvm = r(estimate)
  scalar def lhsc_cvm_se = r(se)
  scalar def lhsc_cvm_z = hsc_cvm/hsc_cvm_se
  scalar def lhsc_cvm_p=2*(1-norm(abs(hsc_cvm_z)))

  lincom [3]_IyXdc2_2000 + [3]_IyXdc3_2000 + [3]_IyXdc4_2000
  scalar def lhsc_ssfvm = r(estimate)
  scalar def lhsc_ssfvm_se = r(se)
  scalar def lhsc_ssfvm_z = lhsc_ssfvm/lhsc_ssfvm_se
  scalar def lhsc_ssfvm_p=2*(1-norm(abs(lhsc_ssfvm_z)))

  lincom [4]_IyXdc2_2000 + [4]_IyXdc3_2000 + [4]_IyXdc4_2000
  scalar def lhsc_ssmvm = r(estimate)
  scalar def lhsc_ssmvm_se = r(se)
  scalar def lhsc_ssmvm_z = lhsc_ssmvm/lhsc_ssmvm_se
  scalar def lhsc_ssmvm_p=2*(1-norm(abs(lhsc_ssmvm_z)))





**Preferred model -- unparsimonious

  xi: mlogit rel_var `base' i.y*abs_aged i.y*o_re i.y*dc2 i.y*dc3 i.y*dc4 , rrr base(2)
  lincom [1]_IyXdc3_2000 + [1]_IyXdc4_2000
  scalar def hsc_mvc = r(estimate)
  scalar def hsc_mvc_se = r(se)
  scalar def hsc_mvc_z = hsc_mvc/hsc_mvc_se
  scalar def hsc_mvc_p=2*(1-norm(abs(hsc_mvc_z)))

  lincom [3]_IyXdc3_2000 + [3]_IyXdc4_2000
  scalar def hsc_ssfvc = r(estimate)
  scalar def hsc_ssfvc_se = r(se)
  scalar def hsc_ssfvc_z = hsc_ssfvc/hsc_ssfvc_se
  scalar def hsc_ssfvc_p=2*(1-norm(abs(hsc_ssfvc_z)))

  lincom [4]_IyXdc3_2000 + [4]_IyXdc4_2000
  scalar def hsc_ssmvc = r(estimate)
  scalar def hsc_ssmvc_se = r(se)
  scalar def hsc_ssmvc_z = hsc_ssmvc/hsc_ssmvc_se
  scalar def hsc_ssmvc_p=2*(1-norm(abs(hsc_ssmvc_z)))


  lincom [1]_IyXdc2_2000 + [1]_IyXdc3_2000 + [1]_IyXdc4_2000
  scalar def lhsc_mvc = r(estimate)
  scalar def lhsc_mvc_se = r(se)
  scalar def lhsc_mvc_z = lhsc_mvc/lhsc_mvc_se
  scalar def lhsc_mvc_p=2*(1-norm(abs(lhsc_mvc_z)))

  lincom [3]_IyXdc2_2000 + [3]_IyXdc3_2000 + [3]_IyXdc4_2000
  scalar def lhsc_ssfvc = r(estimate)
  scalar def lhsc_ssfvc_se = r(se)
  scalar def lhsc_ssfvc_z = lhsc_ssfvc/lhsc_ssfvc_se
  scalar def lhsc_ssfvc_p=2*(1-norm(abs(lhsc_ssfvc_z)))

  lincom [4]_IyXdc2_2000 + [4]_IyXdc3_2000 + [4]_IyXdc4_2000
  scalar def lhsc_ssmvc = r(estimate)
  scalar def lhsc_ssmvc_se = r(se)
  scalar def lhsc_ssmvc_z = lhsc_ssmvc/lhsc_ssmvc_se
  scalar def lhsc_ssmvc_p=2*(1-norm(abs(lhsc_ssmvc_z)))


  xi: mlogit rel_var `base' i.y*abs_aged i.y*o_re i.y*dc2 i.y*dc3 i.y*dc4 , rrr base(3)
  lincom [1]_IyXdc3_2000 + [1]_IyXdc4_2000
  scalar def hsc_mvssf = r(estimate)
  scalar def hsc_mvssf_se = r(se)
  scalar def hsc_mvssf_z = hsc_mvssf/hsc_mvssf_se
  scalar def hsc_mvssf_p=2*(1-norm(abs(hsc_mvssf_z)))

  lincom [2]_IyXdc3_2000 + [2]_IyXdc4_2000
  scalar def hsc_cvssf = r(estimate)
  scalar def hsc_cvssf_se = r(se)
  scalar def hsc_cvssf_z = hsc_cvssf/hsc_cvssf_se
  scalar def hsc_cvssf_p=2*(1-norm(abs(hsc_cvssf_z)))

  lincom [4]_IyXdc3_2000 + [4]_IyXdc4_2000
  scalar def hsc_ssmvssf = r(estimate)
  scalar def hsc_ssmvssf_se = r(se)
  scalar def hsc_ssmvssf_z = hsc_ssmvssf/hsc_ssmvssf_se
  scalar def hsc_ssmvssf_p=2*(1-norm(abs(hsc_ssmvssf_z)))


  lincom [1]_IyXdc2_2000 + [1]_IyXdc3_2000 + [1]_IyXdc4_2000
  scalar def lhsc_mvssf = r(estimate)
  scalar def lhsc_mvssf_se = r(se)
  scalar def lhsc_mvssf_z = lhsc_mvssf/lhsc_mvssf_se
  scalar def lhsc_mvssf_p=2*(1-norm(abs(lhsc_mvssf_z)))

  lincom [2]_IyXdc2_2000 + [2]_IyXdc3_2000 + [2]_IyXdc4_2000
  scalar def lhsc_cvssf = r(estimate)
  scalar def lhsc_cvssf_se = r(se)
  scalar def lhsc_cvssf_z = lhsc_cvssf/lhsc_cvssf_se
  scalar def lhsc_cvssf_p=2*(1-norm(abs(lhsc_cvssf_z)))

  lincom [4]_IyXdc2_2000 + [4]_IyXdc3_2000 + [4]_IyXdc4_2000
  scalar def lhsc_ssmvssf = r(estimate)
  scalar def lhsc_ssmvssf_se = r(se)
  scalar def lhsc_ssmvssf_z = lhsc_ssmvssf/lhsc_ssmvssf_se
  scalar def lhsc_ssmvssf_p=2*(1-norm(abs(lhsc_ssmvssf_z)))



display "RESULT hsc_cvm     "  hsc_cvm
display "RESULT hsc_ssfvm   "  hsc_ssfvm
display "RESULT hsc_ssmvm   "  hsc_ssmvm
display "RESULT hsc_mvc     "  hsc_mvc
display "RESULT hsc_ssfvc   "  hsc_ssfvc
display "RESULT hsc_ssmvc   "  hsc_ssmvc
display "RESULT hsc_mvssf   "  hsc_mvssf
display "RESULT hsc_cvssf   "  hsc_cvssf
display "RESULT hsc_ssmvssf "  hsc_ssmvssf


display "RESULT hsc_cvm_p     "  hsc_cvm_p
display "RESULT hsc_ssfvm_p   "  hsc_ssfvm_p
display "RESULT hsc_ssmvm_p   "  hsc_ssmvm_p
display "RESULT hsc_mvc_p     "  hsc_mvc_p
display "RESULT hsc_ssfvc_p   "  hsc_ssfvc_p
display "RESULT hsc_ssmvc_p   "  hsc_ssmvc_p
display "RESULT hsc_mvssf_p   "  hsc_mvssf_p
display "RESULT hsc_cvssf_p   "  hsc_cvssf_p
display "RESULT hsc_ssmvssf_p "  hsc_ssmvssf_p


display "RESULT lhsc_cvm     "  lhsc_cvm
display "RESULT lhsc_ssfvm   "  lhsc_ssfvm
display "RESULT lhsc_ssmvm   "  lhsc_ssmvm
display "RESULT lhsc_mvc     "  lhsc_mvc
display "RESULT lhsc_ssfvc   "  lhsc_ssfvc
display "RESULT lhsc_ssmvc   "  lhsc_ssmvc
display "RESULT lhsc_mvssf   "  lhsc_mvssf
display "RESULT lhsc_cvssf   "  lhsc_cvssf
display "RESULT lhsc_ssmvssf "  lhsc_ssmvssf


display "RESULT lhsc_cvm_p     "  lhsc_cvm_p
display "RESULT lhsc_ssfvm_p   "  lhsc_ssfvm_p
display "RESULT lhsc_ssmvm_p   "  lhsc_ssmvm_p
display "RESULT lhsc_mvc_p     "  lhsc_mvc_p
display "RESULT lhsc_ssfvc_p   "  lhsc_ssfvc_p
display "RESULT lhsc_ssmvc_p   "  lhsc_ssmvc_p
display "RESULT lhsc_mvssf_p   "  lhsc_mvssf_p
display "RESULT lhsc_cvssf_p   "  lhsc_cvssf_p
display "RESULT lhsc_ssmvssf_p "  lhsc_ssmvssf_p




**Separately by year

  xi: mlogit rel_var `base' i.y*abs_aged i.y*o_re i.y*dc2 i.y*dc3 i.y*dc4  if y == 1990, rrr base(1)
  lincom [2]dc3 + [2]dc4
  scalar def hsc1990_cvm = r(estimate)
  scalar def hsc1990_cvm_se = r(se)
  scalar def hsc1990_cvm_z = hsc1990_cvm/hsc1990_cvm_se
  scalar def hsc1990_cvm_p=2*(1-norm(abs(hsc1990_cvm_z)))


  lincom [3]dc3 + [3]dc4
  scalar def hsc1990_ssfvm = r(estimate)
  scalar def hsc1990_ssfvm_se = r(se)
  scalar def hsc1990_ssfvm_z = hsc1990_ssfvm/hsc1990_ssfvm_se
  scalar def hsc1990_ssfvm_p=2*(1-norm(abs(hsc1990_ssfvm_z)))

  lincom [4]dc3 + [4]dc4
  scalar def hsc1990_ssmvm = r(estimate)
  scalar def hsc1990_ssmvm_se = r(se)
  scalar def hsc1990_ssmvm_z = hsc1990_ssmvm/hsc1990_ssmvm_se
  scalar def hsc1990_ssmvm_p=2*(1-norm(abs(hsc1990_ssmvm_z)))

  lincom [2]dc2 + [2]dc3 + [2]dc4
  scalar def lhsc1990_cvm = r(estimate)
  scalar def lhsc1990_cvm_se = r(se)
  scalar def lhsc1990_cvm_z = hsc1990_cvm/hsc1990_cvm_se
  scalar def lhsc1990_cvm_p=2*(1-norm(abs(hsc1990_cvm_z)))

  lincom [3]dc2 + [3]dc3 + [3]dc4
  scalar def lhsc1990_ssfvm = r(estimate)
  scalar def lhsc1990_ssfvm_se = r(se)
  scalar def lhsc1990_ssfvm_z = lhsc1990_ssfvm/lhsc1990_ssfvm_se
  scalar def lhsc1990_ssfvm_p=2*(1-norm(abs(lhsc1990_ssfvm_z)))

  lincom [4]dc2 + [4]dc3 + [4]dc4
  scalar def lhsc1990_ssmvm = r(estimate)
  scalar def lhsc1990_ssmvm_se = r(se)
  scalar def lhsc1990_ssmvm_z = lhsc1990_ssmvm/lhsc1990_ssmvm_se
  scalar def lhsc1990_ssmvm_p=2*(1-norm(abs(lhsc1990_ssmvm_z)))




  xi: mlogit rel_var `base' i.y*abs_aged i.y*o_re i.y*dc2 i.y*dc3 i.y*dc4  if y == 2000, rrr base(1)

  lincom [2]dc3 + [2]dc4
  scalar def hsc2000_cvm = r(estimate)
  scalar def hsc2000_cvm_se = r(se)
  scalar def hsc2000_cvm_z = hsc2000_cvm/hsc2000_cvm_se
  scalar def hsc2000_cvm_p=2*(1-norm(abs(hsc2000_cvm_z)))


  lincom [3]dc3 + [3]dc4
  scalar def hsc2000_ssfvm = r(estimate)
  scalar def hsc2000_ssfvm_se = r(se)
  scalar def hsc2000_ssfvm_z = hsc2000_ssfvm/hsc2000_ssfvm_se
  scalar def hsc2000_ssfvm_p=2*(1-norm(abs(hsc2000_ssfvm_z)))

  lincom [4]dc3 + [4]dc4
  scalar def hsc2000_ssmvm = r(estimate)
  scalar def hsc2000_ssmvm_se = r(se)
  scalar def hsc2000_ssmvm_z = hsc2000_ssmvm/hsc2000_ssmvm_se
  scalar def hsc2000_ssmvm_p=2*(1-norm(abs(hsc2000_ssmvm_z)))

  lincom [2]dc2 + [2]dc3 + [2]dc4
  scalar def lhsc2000_cvm = r(estimate)
  scalar def lhsc2000_cvm_se = r(se)
  scalar def lhsc2000_cvm_z = hsc2000_cvm/hsc2000_cvm_se
  scalar def lhsc2000_cvm_p=2*(1-norm(abs(hsc2000_cvm_z)))

  lincom [3]dc2 + [3]dc3 + [3]dc4
  scalar def lhsc2000_ssfvm = r(estimate)
  scalar def lhsc2000_ssfvm_se = r(se)
  scalar def lhsc2000_ssfvm_z = lhsc2000_ssfvm/lhsc2000_ssfvm_se
  scalar def lhsc2000_ssfvm_p=2*(1-norm(abs(lhsc2000_ssfvm_z)))

  lincom [4]dc2 + [4]dc3 + [4]dc4
  scalar def lhsc2000_ssmvm = r(estimate)
  scalar def lhsc2000_ssmvm_se = r(se)
  scalar def lhsc2000_ssmvm_z = lhsc2000_ssmvm/lhsc2000_ssmvm_se
  scalar def lhsc2000_ssmvm_p=2*(1-norm(abs(lhsc2000_ssmvm_z)))


  xi: mlogit rel_var `base' i.y*abs_aged i.y*o_re i.y*dc2 i.y*dc3 i.y*dc4  if y == 1990, rrr base(2)

  lincom [1]dc3 + [1]dc4
  scalar def hsc1990_mvc = r(estimate)
  scalar def hsc1990_mvc_se = r(se)
  scalar def hsc1990_mvc_z = hsc1990_mvc/hsc1990_mvc_se
  scalar def hsc1990_mvc_p=2*(1-norm(abs(hsc1990_mvc_z)))

  lincom [3]dc3 + [3]dc4
  scalar def hsc1990_ssfvc = r(estimate)
  scalar def hsc1990_ssfvc_se = r(se)
  scalar def hsc1990_ssfvc_z = hsc1990_ssfvc/hsc1990_ssfvc_se
  scalar def hsc1990_ssfvc_p=2*(1-norm(abs(hsc1990_ssfvc_z)))

  lincom [4]dc3 + [4]dc4
  scalar def hsc1990_ssmvc = r(estimate)
  scalar def hsc1990_ssmvc_se = r(se)
  scalar def hsc1990_ssmvc_z = hsc1990_ssmvc/hsc1990_ssmvc_se
  scalar def hsc1990_ssmvc_p=2*(1-norm(abs(hsc1990_ssmvc_z)))


  lincom [1]dc2 + [1]dc3 + [1]dc4
  scalar def lhsc1990_mvc = r(estimate)
  scalar def lhsc1990_mvc_se = r(se)
  scalar def lhsc1990_mvc_z = lhsc1990_mvc/lhsc1990_mvc_se
  scalar def lhsc1990_mvc_p=2*(1-norm(abs(lhsc1990_mvc_z)))

  lincom [3]dc2 + [3]dc3 + [3]dc4
  scalar def lhsc1990_ssfvc = r(estimate)
  scalar def lhsc1990_ssfvc_se = r(se)
  scalar def lhsc1990_ssfvc_z = lhsc1990_ssfvc/lhsc1990_ssfvc_se
  scalar def lhsc1990_ssfvc_p=2*(1-norm(abs(lhsc1990_ssfvc_z)))

  lincom [4]dc2 + [4]dc3 + [4]dc4
  scalar def lhsc1990_ssmvc = r(estimate)
  scalar def lhsc1990_ssmvc_se = r(se)
  scalar def lhsc1990_ssmvc_z = lhsc1990_ssmvc/lhsc1990_ssmvc_se
  scalar def lhsc1990_ssmvc_p=2*(1-norm(abs(lhsc1990_ssmvc_z)))



  xi: mlogit rel_var `base' i.y*abs_aged i.y*o_re i.y*dc2 i.y*dc3 i.y*dc4  if y == 2000, rrr base(2)

  lincom [1]dc3 + [1]dc4
  scalar def hsc2000_mvc = r(estimate)
  scalar def hsc2000_mvc_se = r(se)
  scalar def hsc2000_mvc_z = hsc2000_mvc/hsc2000_mvc_se
  scalar def hsc2000_mvc_p=2*(1-norm(abs(hsc2000_mvc_z)))

  lincom [3]dc3 + [3]dc4
  scalar def hsc2000_ssfvc = r(estimate)
  scalar def hsc2000_ssfvc_se = r(se)
  scalar def hsc2000_ssfvc_z = hsc2000_ssfvc/hsc2000_ssfvc_se
  scalar def hsc2000_ssfvc_p=2*(1-norm(abs(hsc2000_ssfvc_z)))

  lincom [4]dc3 + [4]dc4
  scalar def hsc2000_ssmvc = r(estimate)
  scalar def hsc2000_ssmvc_se = r(se)
  scalar def hsc2000_ssmvc_z = hsc2000_ssmvc/hsc2000_ssmvc_se
  scalar def hsc2000_ssmvc_p=2*(1-norm(abs(hsc2000_ssmvc_z)))


  lincom [1]dc2 + [1]dc3 + [1]dc4
  scalar def lhsc2000_mvc = r(estimate)
  scalar def lhsc2000_mvc_se = r(se)
  scalar def lhsc2000_mvc_z = lhsc2000_mvc/lhsc2000_mvc_se
  scalar def lhsc2000_mvc_p=2*(1-norm(abs(lhsc2000_mvc_z)))

  lincom [3]dc2 + [3]dc3 + [3]dc4
  scalar def lhsc2000_ssfvc = r(estimate)
  scalar def lhsc2000_ssfvc_se = r(se)
  scalar def lhsc2000_ssfvc_z = lhsc2000_ssfvc/lhsc2000_ssfvc_se
  scalar def lhsc2000_ssfvc_p=2*(1-norm(abs(lhsc2000_ssfvc_z)))

  lincom [4]dc2 + [4]dc3 + [4]dc4
  scalar def lhsc2000_ssmvc = r(estimate)
  scalar def lhsc2000_ssmvc_se = r(se)
  scalar def lhsc2000_ssmvc_z = lhsc2000_ssmvc/lhsc2000_ssmvc_se
  scalar def lhsc2000_ssmvc_p=2*(1-norm(abs(lhsc2000_ssmvc_z)))



  xi: mlogit rel_var `base' i.y*abs_aged i.y*o_re i.y*dc2 i.y*dc3 i.y*dc4  if y == 1990, rrr base(3)


  lincom [1]dc3 + [1]dc4
  scalar def hsc1990_mvssf = r(estimate)
  scalar def hsc1990_mvssf_se = r(se)
  scalar def hsc1990_mvssf_z = hsc1990_mvssf/hsc1990_mvssf_se
  scalar def hsc1990_mvssf_p=2*(1-norm(abs(hsc1990_mvssf_z)))

  lincom [2]dc3 + [2]dc4
  scalar def hsc1990_cvssf = r(estimate)
  scalar def hsc1990_cvssf_se = r(se)
  scalar def hsc1990_cvssf_z = hsc1990_cvssf/hsc1990_cvssf_se
  scalar def hsc1990_cvssf_p=2*(1-norm(abs(hsc1990_cvssf_z)))

  lincom [4]dc3 + [4]dc4
  scalar def hsc1990_ssmvssf = r(estimate)
  scalar def hsc1990_ssmvssf_se = r(se)
  scalar def hsc1990_ssmvssf_z = hsc1990_ssmvssf/hsc1990_ssmvssf_se
  scalar def hsc1990_ssmvssf_p=2*(1-norm(abs(hsc1990_ssmvssf_z)))


  lincom [1]dc2 + [1]dc3 + [1]dc4
  scalar def lhsc1990_mvssf = r(estimate)
  scalar def lhsc1990_mvssf_se = r(se)
  scalar def lhsc1990_mvssf_z = lhsc1990_mvssf/lhsc1990_mvssf_se
  scalar def lhsc1990_mvssf_p=2*(1-norm(abs(lhsc1990_mvssf_z)))

  lincom [2]dc2 + [2]dc3 + [2]dc4
  scalar def lhsc1990_cvssf = r(estimate)
  scalar def lhsc1990_cvssf_se = r(se)
  scalar def lhsc1990_cvssf_z = lhsc1990_cvssf/lhsc1990_cvssf_se
  scalar def lhsc1990_cvssf_p=2*(1-norm(abs(lhsc1990_cvssf_z)))

  lincom [4]dc2 + [4]dc3 + [4]dc4
  scalar def lhsc1990_ssmvssf = r(estimate)
  scalar def lhsc1990_ssmvssf_se = r(se)
  scalar def lhsc1990_ssmvssf_z = lhsc1990_ssmvssf/lhsc1990_ssmvssf_se
  scalar def lhsc1990_ssmvssf_p=2*(1-norm(abs(lhsc1990_ssmvssf_z)))



  xi: mlogit rel_var `base' i.y*abs_aged i.y*o_re i.y*dc2 i.y*dc3 i.y*dc4  if y == 2000, rrr base(3)

  lincom [1]dc3 + [1]dc4
  scalar def hsc2000_mvssf = r(estimate)
  scalar def hsc2000_mvssf_se = r(se)
  scalar def hsc2000_mvssf_z = hsc2000_mvssf/hsc2000_mvssf_se
  scalar def hsc2000_mvssf_p=2*(1-norm(abs(hsc2000_mvssf_z)))

  lincom [2]dc3 + [2]dc4
  scalar def hsc2000_cvssf = r(estimate)
  scalar def hsc2000_cvssf_se = r(se)
  scalar def hsc2000_cvssf_z = hsc2000_cvssf/hsc2000_cvssf_se
  scalar def hsc2000_cvssf_p=2*(1-norm(abs(hsc2000_cvssf_z)))

  lincom [4]dc3 + [4]dc4
  scalar def hsc2000_ssmvssf = r(estimate)
  scalar def hsc2000_ssmvssf_se = r(se)
  scalar def hsc2000_ssmvssf_z = hsc2000_ssmvssf/hsc2000_ssmvssf_se
  scalar def hsc2000_ssmvssf_p=2*(1-norm(abs(hsc2000_ssmvssf_z)))


  lincom [1]dc2 + [1]dc3 + [1]dc4
  scalar def lhsc2000_mvssf = r(estimate)
  scalar def lhsc2000_mvssf_se = r(se)
  scalar def lhsc2000_mvssf_z = lhsc2000_mvssf/lhsc2000_mvssf_se
  scalar def lhsc2000_mvssf_p=2*(1-norm(abs(lhsc2000_mvssf_z)))

  lincom [2]dc2 + [2]dc3 + [2]dc4
  scalar def lhsc2000_cvssf = r(estimate)
  scalar def lhsc2000_cvssf_se = r(se)
  scalar def lhsc2000_cvssf_z = lhsc2000_cvssf/lhsc2000_cvssf_se
  scalar def lhsc2000_cvssf_p=2*(1-norm(abs(lhsc2000_cvssf_z)))

  lincom [4]dc2 + [4]dc3 + [4]dc4
  scalar def lhsc2000_ssmvssf = r(estimate)
  scalar def lhsc2000_ssmvssf_se = r(se)
  scalar def lhsc2000_ssmvssf_z = lhsc2000_ssmvssf/lhsc2000_ssmvssf_se
  scalar def lhsc2000_ssmvssf_p=2*(1-norm(abs(lhsc2000_ssmvssf_z)))




display "RESULT hsc1990_cvm     "  hsc1990_cvm
display "RESULT hsc1990_ssfvm   "  hsc1990_ssfvm
display "RESULT hsc1990_ssmvm   "  hsc1990_ssmvm
display "RESULT hsc1990_mvc     "  hsc1990_mvc
display "RESULT hsc1990_ssfvc   "  hsc1990_ssfvc
display "RESULT hsc1990_ssmvc   "  hsc1990_ssmvc
display "RESULT hsc1990_mvssf   "  hsc1990_mvssf
display "RESULT hsc1990_cvssf   "  hsc1990_cvssf
display "RESULT hsc1990_ssmvssf "  hsc1990_ssmvssf
display "RESULT hsc2000_cvm     "  hsc2000_cvm
display "RESULT hsc2000_ssfvm   "  hsc2000_ssfvm
display "RESULT hsc2000_ssmvm   "  hsc2000_ssmvm
display "RESULT hsc2000_mvc     "  hsc2000_mvc
display "RESULT hsc2000_ssfvc   "  hsc2000_ssfvc
display "RESULT hsc2000_ssmvc   "  hsc2000_ssmvc
display "RESULT hsc2000_mvssf   "  hsc2000_mvssf
display "RESULT hsc2000_cvssf   "  hsc2000_cvssf
display "RESULT hsc2000_ssmvssf "  hsc2000_ssmvssf


display "RESULT hsc1990_cvm_p     "  hsc1990_cvm_p
display "RESULT hsc1990_ssfvm_p   "  hsc1990_ssfvm_p
display "RESULT hsc1990_ssmvm_p   "  hsc1990_ssmvm_p
display "RESULT hsc1990_mvc_p     "  hsc1990_mvc_p
display "RESULT hsc1990_ssfvc_p   "  hsc1990_ssfvc_p
display "RESULT hsc1990_ssmvc_p   "  hsc1990_ssmvc_p
display "RESULT hsc1990_mvssf_p   "  hsc1990_mvssf_p
display "RESULT hsc1990_cvssf_p   "  hsc1990_cvssf_p
display "RESULT hsc1990_ssmvssf_p "  hsc1990_ssmvssf_p
display "RESULT hsc2000_cvm_p     "  hsc2000_cvm_p
display "RESULT hsc2000_ssfvm_p   "  hsc2000_ssfvm_p
display "RESULT hsc2000_ssmvm_p   "  hsc2000_ssmvm_p
display "RESULT hsc2000_mvc_p     "  hsc2000_mvc_p
display "RESULT hsc2000_ssfvc_p   "  hsc2000_ssfvc_p
display "RESULT hsc2000_ssmvc_p   "  hsc2000_ssmvc_p
display "RESULT hsc2000_mvssf_p   "  hsc2000_mvssf_p
display "RESULT hsc2000_cvssf_p   "  hsc2000_cvssf_p
display "RESULT hsc2000_ssmvssf_p "  hsc2000_ssmvssf_p


display "RESULT lhsc1990_cvm     "  lhsc1990_cvm
display "RESULT lhsc1990_ssfvm   "  lhsc1990_ssfvm
display "RESULT lhsc1990_ssmvm   "  lhsc1990_ssmvm
display "RESULT lhsc1990_mvc     "  lhsc1990_mvc
display "RESULT lhsc1990_ssfvc   "  lhsc1990_ssfvc
display "RESULT lhsc1990_ssmvc   "  lhsc1990_ssmvc
display "RESULT lhsc1990_mvssf   "  lhsc1990_mvssf
display "RESULT lhsc1990_cvssf   "  lhsc1990_cvssf
display "RESULT lhsc1990_ssmvssf "  lhsc1990_ssmvssf
display "RESULT lhsc2000_cvm     "  lhsc2000_cvm
display "RESULT lhsc2000_ssfvm   "  lhsc2000_ssfvm
display "RESULT lhsc2000_ssmvm   "  lhsc2000_ssmvm
display "RESULT lhsc2000_mvc     "  lhsc2000_mvc
display "RESULT lhsc2000_ssfvc   "  lhsc2000_ssfvc
display "RESULT lhsc2000_ssmvc   "  lhsc2000_ssmvc
display "RESULT lhsc2000_mvssf   "  lhsc2000_mvssf
display "RESULT lhsc2000_cvssf   "  lhsc2000_cvssf
display "RESULT lhsc2000_ssmvssf "  lhsc2000_ssmvssf


display "RESULT lhsc1990_cvm_p     "  lhsc1990_cvm_p
display "RESULT lhsc1990_ssfvm_p   "  lhsc1990_ssfvm_p
display "RESULT lhsc1990_ssmvm_p   "  lhsc1990_ssmvm_p
display "RESULT lhsc1990_mvc_p     "  lhsc1990_mvc_p
display "RESULT lhsc1990_ssfvc_p   "  lhsc1990_ssfvc_p
display "RESULT lhsc1990_ssmvc_p   "  lhsc1990_ssmvc_p
display "RESULT lhsc1990_mvssf_p   "  lhsc1990_mvssf_p
display "RESULT lhsc1990_cvssf_p   "  lhsc1990_cvssf_p
display "RESULT lhsc1990_ssmvssf_p "  lhsc1990_ssmvssf_p
display "RESULT lhsc2000_cvm_p     "  lhsc2000_cvm_p
display "RESULT lhsc2000_ssfvm_p   "  lhsc2000_ssfvm_p
display "RESULT lhsc2000_ssmvm_p   "  lhsc2000_ssmvm_p
display "RESULT lhsc2000_mvc_p     "  lhsc2000_mvc_p
display "RESULT lhsc2000_ssfvc_p   "  lhsc2000_ssfvc_p
display "RESULT lhsc2000_ssmvc_p   "  lhsc2000_ssmvc_p
display "RESULT lhsc2000_mvssf_p   "  lhsc2000_mvssf_p
display "RESULT lhsc2000_cvssf_p   "  lhsc2000_cvssf_p
display "RESULT lhsc2000_ssmvssf_p "  lhsc2000_ssmvssf_p



#delimit ;

  xi: quietly mlogit rel_var `base' abs_aged o_re dc2 dc3 dc4
              if y == 2000 & (rel_var == 1 | rel_var == 2), rrr base(1) ;
      estimates store cvm ;

  xi: quietly mlogit rel_var `base' abs_aged o_re dc2 dc3 dc4
              if y == 2000 & (rel_var == 1 | rel_var == 3), rrr base(1) ;
      estimates store ssfvm ;

  xi: quietly mlogit rel_var `base' abs_aged o_re dc2 dc3 dc4
              if y == 2000 & (rel_var == 1 | rel_var == 3), rrr base(1) ;
      estimates store ssmvm ;

  xi: quietly mlogit rel_var `base' abs_aged o_re dc2 dc3 dc4
              if y == 2000 & (rel_var == 1 | rel_var == 2), rrr base(2) ;
      estimates store mvc ;

  xi: quietly mlogit rel_var `base' abs_aged o_re dc2 dc3 dc4
              if y == 2000 & (rel_var == 3 | rel_var == 2), rrr base(2) ;
      estimates store ssfvc ;

  xi: quietly mlogit rel_var `base' abs_aged o_re dc2 dc3 dc4
              if y == 2000 & (rel_var == 4 | rel_var == 2), rrr base(2) ;
      estimates store ssmvc ;

  xi: quietly mlogit rel_var `base' abs_aged o_re dc2 dc3 dc4
              if y == 2000 & (rel_var == 1 | rel_var == 3), rrr base(3) ;
      estimates store mvssf ;

  xi: quietly mlogit rel_var `base' abs_aged o_re dc2 dc3 dc4
              if y == 2000 & (rel_var == 2 | rel_var == 3), rrr base(3) ;
      estimates store cvssf ;

  xi: quietly mlogit rel_var `base' abs_aged o_re dc2 dc3 dc4
              if y == 2000 & (rel_var == 4 | rel_var == 3), rrr base(3) ;
      estimates store ssmvssf ;


estimates table cvm    , keep(abs_aged o_re dc2 dc3 dc4) p ;
estimates table ssfvm  , keep(abs_aged o_re dc2 dc3 dc4) p ;
estimates table ssmvm  , keep(abs_aged o_re dc2 dc3 dc4) p ;
estimates table mvc    , keep(abs_aged o_re dc2 dc3 dc4) p ;
estimates table ssfvc  , keep(abs_aged o_re dc2 dc3 dc4) p ;
estimates table ssmvc  , keep(abs_aged o_re dc2 dc3 dc4) p ;
estimates table mvssf  , keep(abs_aged o_re dc2 dc3 dc4) p ;
estimates table cvssf  , keep(abs_aged o_re dc2 dc3 dc4) p ;
estimates table ssmvssf , keep(abs_aged o_re dc2 dc3 dc4) p ;





