clear
macro drop _all
program drop _all
set more off
set linesize 80
version 9.0

capture log close
log using "/project/graf_schwartz/demresearch/percent_h_20to34.log",replace

set mem 1500m



**************************************************************************
* SAMPLE: Use only couples in which both partners are between the ages of*
* 20-34                                                                  *
**************************************************************************

************************************************************************
* This file uses the alternate version of race/ethnicity in which      *
* biracial whites are coded as white                                   *
************************************************************************





use if (age0 >= 20 & age0 <= 34) & (age1 >= 20 & age1 <= 34)  using "/project/graf_schwartz/demresearch/couple_2000.dta"
gen y = 2000
gen year = 2000

append using "/project/graf_schwartz/demresearch/couple_1990.dta"
replace y = 1990 if y == .
replace year = 1990 if year == .


svyset [pweight=hhwt]


**********
* SELECT *
**********

keep if (age0 >= 20 & age0 <= 34) & (age1 >= 20 & age1 <= 34)



***                          ***
*** SAMPLE SIZES - W IMPUTED ***
***                          ***

gen round_wgt = round(hhwt, 1)

bysort y: tab rel_var
bysort y: tab rel_var [fw=round_wgt]

bysort year: tab rel_var
bysort year: tab rel_var [fw=round_wgt]




*drop couples in which either partners' marital status was imputed

gen marimp = (qmarst0 ~= 0 | qmarst1 ~= 0)


bysort y rel_var: tab marimp


drop if marimp == 1


***                              ***
*** SAMPLE SIZES - W/OUT IMPUTED ***
***                              ***

bysort y: tab rel_var
bysort y: tab rel_var [fw=round_wgt]


*Note that the survey command is equal to the frequency weights.
*The frequency weights take much less time to run so I use frequency weights
*for the crosstabs

*svy: tab rel_var if y == 1990



*** Use the person weight of the householder.  This means the sample
*** is representative of relationships among 20-34 year old household
*** heads.



***USE ALTERNATIVE RACE VARIABLE***

   replace re1 = re21 if y == 2000 | y == 2007
   replace re0 = re20 if y == 2000 | y == 2007

   drop re2*


#delimit ;

**Make race dummies ;

quietly tab re0, gen(re0d) ;
quietly tab re1, gen(re1d) ;


tab re0, miss  ;
tab re1, miss  ;

#delimit cr

bysort rel_var: tab re0 re1, cell nofreq


foreach x in re educ age {
 gen o_`x' = (`x'0 == `x'1)
}

bysort rel_var: tab o_re


keep serial y year re0* re1* educ* age* o* rel_var hhwt

expand 2
bysort serial year: gen dup = _n

*Dup should be 1s and 2s. It works.
tab dup

*Trying to get homogamy for individuals by couple type. Obviously
*these observations are not independent because they come from couples.
*

sort serial year dup

foreach x in re educ age {
 by serial year: replace `x'0 = `x'1[_n-1] if dup == 2
 by serial year: replace `x'1 = `x'0[_n-1] if dup == 2
}

**Sample size
bysort y: tab rel_var

**Percentage homogamous for individuals by year and couple type

bysort y: tab o_re rel_var [aw=hhwt], col  nofreq
bysort y: tab o_educ rel_var [aw=hhwt], col  nofreq

**Correlation btwn partners' ages by year and couple type

bysort y rel_var: corr age0 age1 [aw=hhwt]


log close
